package handler

import (
	"apskel-pos-be/internal/contract"
	"context"
	"github.com/google/uuid"
)

type UserService interface {
	CreateUser(ctx context.Context, req *contract.CreateUserRequest) (*contract.UserResponse, error)
	UpdateUser(ctx context.Context, id uuid.UUID, req *contract.UpdateUserRequest) (*contract.UserResponse, error)
	DeleteUser(ctx context.Context, id uuid.UUID) error
	GetUserByID(ctx context.Context, id uuid.UUID) (*contract.UserResponse, error)
	GetUserByEmail(ctx context.Context, email string) (*contract.UserResponse, error)
	ListUsers(ctx context.Context, req *contract.ListUsersRequest) (*contract.ListUsersResponse, error)
	ChangePassword(ctx context.Context, userID uuid.UUID, req *contract.ChangePasswordRequest) error
	ActivateUser(ctx context.Context, userID uuid.UUID) error
	DeactivateUser(ctx context.Context, userID uuid.UUID) error
	UpdateUserOutlet(ctx context.Context, userID uuid.UUID, req *contract.UpdateUserOutletRequest) (*contract.UserResponse, error)
}
